#ifndef CHANNELMAP_SERVICE__CC
#define CHANNELMAP_SERVICE__CC
////////////////////////////////////////////////////////////////////////
/// \file ChannelMap_service.cc
///  
/// \brief A service to manipulate channel map, containing activity
///
/// \author Andrey Sheshukov
////////////////////////////////////////////////////////////////////////

#include "OnlineCalibration/StaticMapService.h"

namespace novaddt{

StaticMapService::StaticMapService
    (fhicl::ParameterSet const& p, art::ActivityRegistry& reg):
    fMapSource(p.get<std::string>("source"))
{
    mf::LogInfo("ChannelMapService")<<"\t config:"
    <<"\n\tmap source:"<<fMapSource;
    readMapFromFile(fMapSource); 
}

void StaticMapService::readMapFromFile(const std::string& fname)
{
        mf::LogInfo("ChannelMapService")<<"read map from file \""<<fname<<"\"";

        std::ifstream s(fname.data(),std::ifstream::binary);
        if(!s.good()){
            mf::LogError("ChannelMapService")<<" error opening file \""<<fname<<"\"";
            return;
        }
        
        {
            size_t length = sizeof(fMap);
            char *buffer=reinterpret_cast<char*>(&fMap);
            s.read(buffer,length);
            mf::LogInfo("ChannelMapService")<<"read successfully";
        }
}
void StaticMapService::saveMapToFile(const std::string& fname)
{
        mf::LogInfo("ChannelMapService")<<"save map to file \""<<fname<<"\"";

        std::ofstream s(fname.data(),std::ofstream::binary);
        if(!s.good()){
            mf::LogError("ChannelMapService")<<" error opening file \""<<fname<<"\"";
            return;
        }
        
        size_t length = sizeof(fMap);
        char *buffer=reinterpret_cast<char*>(&fMap);
        s.write(buffer,length);
}

DEFINE_ART_SERVICE(StaticMapService);
}
#endif
